@@ -2,16 +2,13 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from . import account
-from . import configuration
-from . import company
-from . import fiscalyear
-from . import journal
-from . import move
-from . import move_template
-from . import party
-from . import period
-from . import tax
+
+from . import (
+    account, company, configuration, fiscalyear, journal, move, move_template,
+    party, period, tax)
+from .move import MoveLineMixin
+
+__all__ = ['register', 'MoveLineMixin']
 
 
 def register():
@@ -27,7 +24,7 @@ def register():
         account.AccountParty,
         account.AccountDeferral,
         account.AccountTax,
-        account.OpenChartAccountStart,
+        account.AccountContext,
         account.GeneralLedgerAccount,
         account.GeneralLedgerAccountContext,
         account.GeneralLedgerAccountParty,
@@ -47,6 +44,7 @@ def register():
         configuration.ConfigurationDefaultAccount,
         configuration.DefaultTaxRule,
         configuration.Sequence,
+        configuration.Journal,
         period.Period,
         journal.Journal,
         journal.JournalSequence,
@@ -56,18 +54,24 @@ def register():
         move.Reconciliation,
         configuration.ConfigurationTaxRounding,
         move.Line,
+        move.LineReceivablePayableContext,
         move.WriteOff,
         move.OpenJournalAsk,
         move.ReconcileLinesWriteOff,
+        move.ReconcileStart,
         move.ReconcileShow,
         move.CancelMovesDefault,
         move.GroupLinesStart,
+        move.RescheduleLinesStart,
+        move.RescheduleLinesPreview,
+        move.RescheduleLinesTerm,
+        move.DelegateLinesStart,
         tax.TaxGroup,
         tax.TaxCodeTemplate,
         tax.TaxCode,
         tax.TaxCodeLineTemplate,
         tax.TaxCodeLine,
-        tax.OpenChartTaxCodeStart,
+        tax.TaxCodeContext,
         tax.TaxTemplate,
         tax.Tax,
         tax.TaxLine,
@@ -91,7 +95,6 @@ def register():
     Pool.register(
         account.OpenType,
         fiscalyear.BalanceNonDeferral,
-        account.OpenChartAccount,
         account.CreateChart,
         account.UpdateChart,
         account.OpenGeneralLedgerAccountParty,
@@ -102,8 +105,9 @@ def register():
         move.Reconcile,
         move.CancelMoves,
         move.GroupLines,
+        move.RescheduleLines,
+        move.DelegateLines,
         move_template.CreateMove,
-        tax.OpenChartTaxCode,
         tax.OpenTaxCode,
         tax.TestTax,
         party.PartyReplace,
